@@ -184,11 +184,14 @@ update_info_from_link (NautilusDesktopIconFile *icon_file)
 	file->details->can_mount = FALSE;
 	file->details->can_unmount = FALSE;
 	file->details->can_eject = FALSE;
+	if (file->details->mount) {
+		g_object_unref (file->details->mount);
+	}
 	mount = nautilus_desktop_link_get_mount (link);
+	file->details->mount = mount;
 	if (mount) {
 		file->details->can_unmount = g_mount_can_unmount (mount);
 		file->details->can_eject = g_mount_can_eject (mount);
-		g_object_unref (mount);
 	}
 	
 	file->details->file_info_is_up_to_date = TRUE;
@@ -202,10 +205,8 @@ update_info_from_link (NautilusDesktopIconFile *icon_file)
 		g_object_unref (file->details->icon);
 	}
 	file->details->icon = nautilus_desktop_link_get_icon (link);
-	if (file->details->activation_location) {
-		g_object_unref (file->details->activation_location);
-	}
-	file->details->activation_location = nautilus_desktop_link_get_activation_location (link);
+	g_free (file->details->activation_uri);
+	file->details->activation_uri = nautilus_desktop_link_get_activation_uri (link);
 	file->details->got_link_info = TRUE;
 	file->details->link_info_is_up_to_date = TRUE;
 
@@ -305,15 +306,15 @@ static void
 nautilus_desktop_icon_file_unmount (NautilusFile *file)
 {
 	NautilusDesktopIconFile *desktop_file;
-    GMount *mount;
-    
-    desktop_file = NAUTILUS_DESKTOP_ICON_FILE (file);
-    if (desktop_file) {
-    	mount = nautilus_desktop_link_get_mount (desktop_file->details->link);
-       	if (mount != NULL) {
-       		nautilus_file_operations_unmount_mount (NULL, mount, FALSE, TRUE);
-       	}
-    }
+	GMount *mount;
+	
+	desktop_file = NAUTILUS_DESKTOP_ICON_FILE (file);
+	if (desktop_file) {
+		mount = nautilus_desktop_link_get_mount (desktop_file->details->link);
+		if (mount != NULL) {
+			nautilus_file_operations_unmount_mount (NULL, mount, FALSE, TRUE);
+		}
+	}
 	
 }
 
@@ -321,15 +322,15 @@ static void
 nautilus_desktop_icon_file_eject (NautilusFile *file)
 {
 	NautilusDesktopIconFile *desktop_file;
-    GMount *mount;
-    
-    desktop_file = NAUTILUS_DESKTOP_ICON_FILE (file);
-    if (desktop_file) {
-    	mount = nautilus_desktop_link_get_mount (desktop_file->details->link);
-       	if (mount != NULL) {
-       		nautilus_file_operations_unmount_mount (NULL, mount, TRUE, TRUE);
-       	}
-    }
+	GMount *mount;
+	
+	desktop_file = NAUTILUS_DESKTOP_ICON_FILE (file);
+	if (desktop_file) {
+		mount = nautilus_desktop_link_get_mount (desktop_file->details->link);
+		if (mount != NULL) {
+			nautilus_file_operations_unmount_mount (NULL, mount, TRUE, TRUE);
+		}
+	}
 }
 
 
