@@ -39,12 +39,6 @@
 #define NAUTILUS_FILE_TOP_LEFT_TEXT_MAXIMUM_LINES               5
 #define NAUTILUS_FILE_TOP_LEFT_TEXT_MAXIMUM_BYTES               1024
 
-#define NAUTILUS_FILE_DEFAULT_FILE_INFO_OPTIONS \
-	(GNOME_VFS_FILE_INFO_FOLLOW_LINKS |	\
-	 GNOME_VFS_FILE_INFO_GET_MIME_TYPE |	  \
-	 GNOME_VFS_FILE_INFO_GET_SELINUX_CONTEXT |	\
-	 GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS)
-
 #define NAUTILUS_FILE_DEFAULT_ATTRIBUTES				\
 	"standard::*,access::*,mountable::*,time::*,unix::*,owner::*,selinux::*,thumbnail::*,id::filesystem,trash::orig-path"
 
@@ -81,6 +75,10 @@ struct NautilusFileDetails
 	guint32 permissions;
 	int uid; /* -1 is none */
 	int gid; /* -1 is none */
+
+	eel_ref_str owner;
+	eel_ref_str owner_real;
+	eel_ref_str group;
 	
 	time_t atime; /* 0 is unknown */
 	time_t mtime; /* 0 is unknown */
@@ -113,7 +111,7 @@ struct NautilusFileDetails
 
 	/* Info you might get from a link (.desktop, .directory or nautilus link) */
 	char *custom_icon;
-	GFile *activation_location;
+	char *activation_uri;
 
 	/* used during DND, for checking whether source and destination are on
 	 * the same file system.
@@ -185,7 +183,7 @@ struct NautilusFileDetails
 	eel_boolean_bit got_link_info                 : 1;
 	eel_boolean_bit link_info_is_up_to_date       : 1;
 	eel_boolean_bit got_custom_display_name       : 1;
-	eel_boolean_bit got_custom_activation_location : 1;
+	eel_boolean_bit got_custom_activation_uri     : 1;
 
 	eel_boolean_bit thumbnail_is_up_to_date       : 1;
 	eel_boolean_bit thumbnail_wants_original      : 1;
@@ -198,6 +196,8 @@ struct NautilusFileDetails
 	eel_boolean_bit has_open_window               : 1;
 
 	eel_boolean_bit is_launcher                   : 1;
+	eel_boolean_bit is_trusted_link               : 1;
+	eel_boolean_bit is_foreign_link               : 1;
 	eel_boolean_bit is_symlink                    : 1;
 	eel_boolean_bit is_mountpoint                 : 1;
 	eel_boolean_bit is_hidden                     : 1;
@@ -264,6 +264,8 @@ gboolean      nautilus_file_set_display_name               (NautilusFile
 							    const char             *display_name,
 							    const char             *edit_name,
 							    gboolean                custom);
+void          nautilus_file_set_mount                      (NautilusFile           *file,
+							    GMount                 *mount);
 
 /* Return true if the top lefts of files in this directory should be
  * fetched, according to the preference settings.
