@@ -547,6 +547,18 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_INTEGER,
 	  GINT_TO_POINTER (3)
 	},
+	{ NAUTILUS_PREFERENCES_MOUSE_USE_EXTRA_BUTTONS,
+	  PREFERENCE_BOOLEAN,
+	  GINT_TO_POINTER (TRUE)
+	},
+	{ NAUTILUS_PREFERENCES_MOUSE_FORWARD_BUTTON,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (8)
+	},
+	{ NAUTILUS_PREFERENCES_MOUSE_BACK_BUTTON,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (9)
+	},
 	{ NULL }
 };
 
