@@ -42,6 +42,7 @@
 #include <gtk/gtk.h>
 #include <gio/gio.h>
 #include <glib/gi18n.h>
+#include <eel/eel-gtk-extensions.h>
 #include <eel/eel-preferences.h>
 #include <libnautilus-extension/nautilus-menu-provider.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
@@ -53,6 +54,7 @@
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-search-engine.h>
 #include <libnautilus-private/nautilus-signaller.h>
+#include <libnautilus-private/nautilus-trash-monitor.h>
 #include <string.h>
 
 #define MENU_PATH_EXTENSION_ACTIONS                     "/MenuBar/File/Extension Actions"
@@ -589,7 +591,7 @@ menu_item_select_cb (GtkMenuItem *proxy,
 	GtkAction *action;
 	char *message;
 
-	action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
+	action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (proxy));
 	g_return_if_fail (action != NULL);
 	
 	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
@@ -622,13 +624,7 @@ get_event_widget (GtkWidget *proxy)
 		/* Menu items already forward middle clicks */
 		widget = NULL;
 	} else if (GTK_IS_MENU_TOOL_BUTTON (proxy)) {
-		/**
-		 * The menu tool button's button is the first child
-		 * of the child hbox.
-		 */
-		GtkContainer *container =
-			GTK_CONTAINER (gtk_bin_get_child (GTK_BIN (proxy)));
-		widget = GTK_WIDGET (gtk_container_get_children (container)->data);
+		widget = eel_gtk_menu_tool_button_get_button (GTK_MENU_TOOL_BUTTON (proxy));
 	} else if (GTK_IS_TOOL_BUTTON (proxy)) {
 		/* The tool button's button is the direct child */
 		widget = gtk_bin_get_child (GTK_BIN (proxy));
@@ -737,6 +733,39 @@ connect_proxy_cb (GtkUIManager *manager,
 	}
 }
 
+static void
+trash_state_changed_cb (NautilusTrashMonitor *monitor,
+			gboolean state,
+			NautilusWindow *window)
+{
+	GtkActionGroup *action_group;
+	GtkAction *action;
+	GIcon *gicon;
+
+	action_group = window->details->main_action_group;
+	action = gtk_action_group_get_action (action_group, "Go to Trash");
+
+	gicon = nautilus_trash_monitor_get_icon ();
+
+	if (gicon) {
+		g_object_set (action, "gicon", gicon, NULL);
+		g_object_unref (gicon);
+	}
+}
+
+static void
+nautilus_window_initialize_trash_icon_monitor (NautilusWindow *window)
+{
+	NautilusTrashMonitor *monitor;
+
+	monitor = nautilus_trash_monitor_get ();
+
+	trash_state_changed_cb (monitor, TRUE, window);
+
+	g_signal_connect (monitor, "trash_state_changed",
+			  G_CALLBACK (trash_state_changed_cb), window);
+}
+
 static const GtkActionEntry main_entries[] = {
   /* name, stock id, label */  { "File", NULL, N_("_File") },
   /* name, stock id, label */  { "Edit", NULL, N_("_Edit") },
@@ -894,6 +923,7 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 	ui = nautilus_ui_string_get ("nautilus-shell-ui.xml");
 	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
+	nautilus_window_initialize_trash_icon_monitor (window);
 	nautilus_window_initialize_bookmarks_menu (window);
 }
 
@@ -1028,4 +1058,14 @@ nautilus_window_load_extension_menus (NautilusWindow *window)
 	}
 }
 
+void
+nautilus_window_remove_trash_monitor_callback (NautilusWindow *window)
+{
+	NautilusTrashMonitor *monitor;
+
+	monitor = nautilus_trash_monitor_get ();
+
+	g_signal_handlers_disconnect_by_func (monitor,
+					      trash_state_changed_cb, window);
+}
 
